<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="500px"
            :before-close="handleClose"
        >
            <el-form :model="state.form" size="default" ref="typeRef" :rules="state.formRules" label-width="110px" >
                <el-form-item label="评价类型:" prop="type">
                    <el-input v-model.trim="state.form.type"></el-input>
                </el-form-item>
            </el-form>
            <template #footer>
                    <span class="dialog-footer">
                        <el-button @click="handleClose" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default">确认</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";

const dialogVisible = ref(false);
const title = ref("");
const typeRef = ref();
const isReview = ref(false);
const state = reactive({
    form: {
        type: ''
    },
    formRules:{
        type: [{ required: true, message: '请输入评价类型', trigger: 'blur' }],
    },

})

const openDialog = (type, value) => {
    isReview.value = false;
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
    if(type === 'edit') {
        state.form = value;
    }
    dialogVisible.value = true;
}

const onSubmit = async () => {
    const valid = await typeRef.value.validate();
    if(valid){
        typeRef.value.clearValidate();
        reset();
        dialogVisible.value = false;

    }
}

const handleClose = () => {
    typeRef.value.clearValidate();
    reset();
    dialogVisible.value = false;

}
const reset = () => {
    state.form = {
        type: ""
    }
}
const handleRemove = (file, fileList) => {
    console.log(file, fileList);
}
const handlePreview = (uploadFile) => {
    console.log(uploadFile)
}
const beforeRemove = (file, fileList) => {
    return this.$confirm(`确定移除 ${ file.name }？`);
}


defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
